@@ -1,5 +1,5 @@
 const char COPYRIGHT[] =
-          "Copyright (c) 1998-2015 Stephen Williams (steve@icarus.com)";
+          "Copyright (c) 1998-2017 Stephen Williams (steve@icarus.com)";
 
 /*
  *    This source code is free software; you can redistribute it
@@ -933,16 +933,22 @@ int main(int argc, char*argv[])
       switch (generation_flag) {
         case GN_VER2012:
 	  lexor_keyword_mask |= GN_KEYWORDS_1800_2012;
+	  // fallthrough
         case GN_VER2009:
 	  lexor_keyword_mask |= GN_KEYWORDS_1800_2009;
+	  // fallthrough
         case GN_VER2005_SV:
 	  lexor_keyword_mask |= GN_KEYWORDS_1800_2005;
+	  // fallthrough
         case GN_VER2005:
 	  lexor_keyword_mask |= GN_KEYWORDS_1364_2005;
+	  // fallthrough
         case GN_VER2001:
 	  lexor_keyword_mask |= GN_KEYWORDS_1364_2001_CONFIG;
+	  // fallthrough
         case GN_VER2001_NOCONFIG:
 	  lexor_keyword_mask |= GN_KEYWORDS_1364_2001;
+	  // fallthrough
         case GN_VER1995:
 	  lexor_keyword_mask |= GN_KEYWORDS_1364_1995;
       }
@@ -1037,9 +1043,8 @@ int main(int argc, char*argv[])
 		  pform_dump(out, cur->second);
 	    }
 	    out << "PFORM DUMP $ROOT CLASSES:" << endl;
-	    for (map<perm_string,PClass*>::iterator cur = pform_classes.begin()
-		       ; cur != pform_classes.end() ; ++ cur) {
-		  pform_dump(out, cur->second);
+	    for (size_t idx = 0 ; idx < pform_classes.size() ; idx += 1) {
+		  pform_dump(out, pform_classes[idx]);
 	    }
 	    out << "PFORM DUMP PACKAGES:" << endl;
 	    for (map<perm_string,PPackage*>::iterator pac = pform_packages.begin()
