@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2016 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2001-2017 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -1665,3 +1665,38 @@ NetScope* find_method_containing_scope(const LineInfo&, NetScope*scope)
 
       return scope;
 }
+
+
+/*
+ * Print a warning if we find a mixture of default and explicit timescale
+ * based delays in the design, since this is likely an error.
+ */
+void check_for_inconsistent_delays(NetScope*scope)
+{
+      static bool used_implicit_timescale = false;
+      static bool used_explicit_timescale = false;
+      static bool display_ts_dly_warning = true;
+
+      if (scope->time_from_timescale())
+	    used_explicit_timescale = true;
+      else
+	    used_implicit_timescale = true;
+
+      if (display_ts_dly_warning &&
+	  used_explicit_timescale &&
+	  used_implicit_timescale) {
+	    if (gn_system_verilog()) {
+		  cerr << "warning: Found both default and explicit "
+			  "timescale based delays. Use" << endl;
+		  cerr << "       : -Wtimescale to find the design "
+			  "element(s) with no explicit" << endl;
+		  cerr << "       : timescale." << endl;
+	    } else {
+		  cerr << "warning: Found both default and "
+			  "`timescale based delays. Use" << endl;
+		  cerr << "       : -Wtimescale to find the "
+			  "module(s) with no `timescale." << endl;
+	    }
+	    display_ts_dly_warning = false;
+      }
+}
