@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2015 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2000-2018 Stephen Williams (steve@icarus.com)
  * Copyright CERN 2013 / Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
@@ -281,6 +281,13 @@ ivl_scope_t dll_target::find_scope(ivl_design_s &des, const NetScope*cur)
 		  return scope;
       }
 
+      for (map<const NetScope*,ivl_scope_t>::iterator idx = des.root_tasks.begin()
+		 ; idx != des.root_tasks.end() ; ++ idx) {
+	    ivl_scope_t scope = find_scope_from_root(idx->second, cur);
+	    if (scope)
+		  return scope;
+      }
+
       return 0;
 }
 
@@ -2482,6 +2489,7 @@ void dll_target::scope(const NetScope*net)
 		case NetScope::PACKAGE:
 		  cerr << "?:?" << ": internal error: "
 		       << "Package scopes should not have parents." << endl;
+		  // fallthrough
 		case NetScope::MODULE:
 		  scop->type_ = IVL_SCT_MODULE;
 		  scop->tname_ = net->module_name();
