@@ -117,13 +117,18 @@ static void draw_binary_vec4_arith(ivl_expr_t expr)
       unsigned rwid = ivl_expr_width(re);
       unsigned ewid = ivl_expr_width(expr);
 
-      int signed_flag = ivl_expr_signed(le) && ivl_expr_signed(re) ? 1 : 0;
+      int is_power_op = ivl_expr_opcode(expr) == 'p' ? 1 : 0;
+
+	/* The power operation differs from the other arithmetic operations
+	   in that we only use the signed version of the operation if the
+	   right hand operand (the exponent) is signed. */
+      int signed_flag = (ivl_expr_signed(le) || is_power_op) && ivl_expr_signed(re) ? 1 : 0;
       const char*signed_string = signed_flag? "/s" : "";
 
-	/* All the arithmetic operations handled here require that the
-	   operands (and the result) be the same width. We further
-	   assume that the core has not given us an operand wider then
-	   the expression width. So padd operands as needed. */
+	/* All the arithmetic operations handled here (except for the power
+	   operation) require that the operands (and the result) be the same
+	   width. We further assume that the core has not given us an operand
+	   wider then the expression width. So pad operands as needed. */
       draw_eval_vec4(le);
       if (lwid != ewid) {
 	    fprintf(vvp_out, "    %%pad/%c %u;\n", ivl_expr_signed(le)? 's' : 'u', ewid);
@@ -150,7 +155,7 @@ static void draw_binary_vec4_arith(ivl_expr_t expr)
       }
 
       draw_eval_vec4(re);
-      if (rwid != ewid) {
+      if ((rwid != ewid) && !is_power_op) {
 	    fprintf(vvp_out, "    %%pad/%c %u;\n", ivl_expr_signed(re)? 's' : 'u', ewid);
       }
 
@@ -171,11 +176,6 @@ static void draw_binary_vec4_arith(ivl_expr_t expr)
 	    fprintf(vvp_out, "    %%mod%s;\n", signed_string);
 	    break;
 	  case 'p':
-	      /* Note that the power operator is signed if EITHER of
-		 the operands is signed. This is different from other
-		 arithmetic operators. */
-	    if (ivl_expr_signed(le) || ivl_expr_signed(re))
-		  signed_string = "/s";
 	    fprintf(vvp_out, "    %%pow%s;\n", signed_string);
 	    break;
 
