@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2015 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1999-2018 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -406,31 +406,31 @@ static unsigned int get_format_char(char **rtn, int ljust, int plus,
         vpi_printf("WARNING: %s:%d: missing argument for %s%s.\n",
                    info->filename, info->lineno, info->name, fmtb);
       } else {
-        value.format = vpiStringVal;
+        value.format = vpiIntVal;
         vpi_get_value(info->items[*idx], &value);
         if (value.format == vpiSuppressVal) {
           vpi_printf("WARNING: %s:%d: incompatible value for %s%s.\n",
                      info->filename, info->lineno, info->name, fmtb);
         } else {
-          char ch = value.value.str[strlen(value.value.str)-1];
-
-          /* If the default buffer is too small, make it big enough. */
-          size = width + 1;
-          if (size > ini_size) result = realloc(result, size*sizeof(char));
+          char ch = value.value.integer;
 
           /* If the width is less than one then use a width of one. */
           if (width < 1) width = 1;
+          size = width + 1;
+          assert(size <= ini_size);
+
           if (ljust == 0) {
             if (width > 1) {
-              char *cp = malloc((width+1)*sizeof(char));
-              memset(cp, (ld_zero == 1 ? '0': ' '), width-1);
-              cp[width-1] = ch;
-              cp[width] = '\0';
-              sprintf(result, "%*s", width, cp);
-              free(cp);
-            } else sprintf(result, "%c", ch);
-          } else sprintf(result, "%-*c", width, ch);
-          size = strlen(result) + 1;
+              memset(result, (ld_zero == 1 ? '0': ' '), width-1);
+            }
+            result[width-1] = ch;
+          } else {
+            result[0] = ch;
+            if (width > 1) {
+              memset(result+1, ' ', width-1);
+            }
+          }
+          result[width] = '\0';
         }
       }
       break;
@@ -1138,7 +1138,7 @@ static int sys_check_args(vpiHandle callh, vpiHandle argv, const PLI_BYTE8*name,
 			           name, vpi_get_str(vpiType, arg));
 			ret = 1;
 		  }
-
+		  // fallthrough
 	      case vpiConstant:
 	      case vpiParameter:
 	      case vpiNet:
@@ -1887,6 +1887,8 @@ static const char *pts_convert(int value)
 {
       const char *string;
       switch (value) {
+            case   2: string = "100s";  break;
+            case   1: string = "10s";   break;
             case   0: string = "1s";    break;
             case  -1: string = "100ms"; break;
             case  -2: string = "10ms";  break;
