@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2013 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2001-2016 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -26,13 +26,13 @@
 # include  <cmath>
 
 vvp_arith_::vvp_arith_(unsigned wid)
-: wid_(wid), x_val_(wid)
+: wid_(wid), op_a_(wid), op_b_(wid), x_val_(wid)
 {
-      for (unsigned idx = 0 ;  idx < wid ;  idx += 1)
+      for (unsigned idx = 0 ;  idx < wid ;  idx += 1) {
+	    op_a_ .set_bit(idx, BIT4_Z);
+	    op_b_ .set_bit(idx, BIT4_Z);
 	    x_val_.set_bit(idx, BIT4_X);
-
-      op_a_ = x_val_;
-      op_b_ = x_val_;
+      }
 }
 
 void vvp_arith_::dispatch_operand_(vvp_net_ptr_t ptr, vvp_vector4_t bit)
@@ -51,6 +51,12 @@ void vvp_arith_::dispatch_operand_(vvp_net_ptr_t ptr, vvp_vector4_t bit)
       }
 }
 
+void vvp_arith_::recv_vec4_pv(vvp_net_ptr_t ptr, const vvp_vector4_t&bit,
+			      unsigned base, unsigned wid, unsigned vwid,
+                              vvp_context_t ctx)
+{
+      recv_vec4_pv_(ptr, bit, base, wid, vwid, ctx);
+}
 
 vvp_arith_abs::vvp_arith_abs()
 {
@@ -82,6 +88,13 @@ void vvp_arith_abs::recv_vec4(vvp_net_ptr_t ptr, const vvp_vector4_t&bit,
       ptr.ptr()->send_vec4(out, 0);
 }
 
+void vvp_arith_abs::recv_vec4_pv(vvp_net_ptr_t ptr, const vvp_vector4_t&bit,
+				 unsigned base, unsigned wid, unsigned vwid,
+				 vvp_context_t ctx)
+{
+      recv_vec4_pv_(ptr, bit, base, wid, vwid, ctx);
+}
+
 void vvp_arith_abs::recv_real(vvp_net_ptr_t ptr, double bit,
                               vvp_context_t)
 {
@@ -121,6 +134,13 @@ void vvp_arith_cast_real::recv_vec4(vvp_net_ptr_t ptr, const vvp_vector4_t&bit,
       ptr.ptr()->send_real(val, 0);
 }
 
+void vvp_arith_cast_real::recv_vec4_pv(vvp_net_ptr_t ptr, const vvp_vector4_t&bit,
+				       unsigned base, unsigned wid, unsigned vwid,
+				       vvp_context_t ctx)
+{
+      recv_vec4_pv_(ptr, bit, base, wid, vwid, ctx);
+}
+
 vvp_arith_cast_vec2::vvp_arith_cast_vec2(unsigned wid)
 : wid_(wid)
 {
@@ -143,6 +163,13 @@ void vvp_arith_cast_vec2::recv_vec4(vvp_net_ptr_t ptr, const vvp_vector4_t&bit,
       ptr.ptr()->send_vec4(vector2_to_vector4(tmp,wid_), 0);
 }
 
+void vvp_arith_cast_vec2::recv_vec4_pv(vvp_net_ptr_t ptr, const vvp_vector4_t&bit,
+				       unsigned base, unsigned wid, unsigned vwid,
+				       vvp_context_t ctx)
+{
+      recv_vec4_pv_(ptr, bit, base, wid, vwid, ctx);
+}
+
 // Division
 
 vvp_arith_div::vvp_arith_div(unsigned wid, bool signed_flag)
