@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2014 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2001-2018 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -209,8 +209,12 @@ static value_callback* make_value_change(p_cb_data data)
       }
 
 	// Special case: the target object is a vpiPartSelect
-      if (data->obj->get_type_code() == vpiPartSelect)
-	    return make_value_change_part(data);
+      if (data->obj->get_type_code() == vpiPartSelect) {
+            if (data->obj->vpi_handle(vpiArray))
+	        return vpip_array_word_change(data);
+            else
+	        return make_value_change_part(data);
+      }
 
       if (data->obj->get_type_code() == vpiMemoryWord)
 	    return vpip_array_word_change(data);
@@ -780,6 +784,15 @@ void vvp_signal_value::get_signal_value(struct t_vpi_value*vp)
       }
 }
 
+static double vlg_round(double rval)
+{
+      if (rval >= 0.0) {
+            return floor(rval + 0.5);
+      } else {
+            return ceil(rval - 0.5);
+      }
+}
+
 static void real_signal_value(struct t_vpi_value*vp, double rval)
 {
       char*rbuf = (char *) need_result_buf(64 + 1, RBUF_VAL);
@@ -787,7 +800,7 @@ static void real_signal_value(struct t_vpi_value*vp, double rval)
       switch (vp->format) {
 	  case vpiObjTypeVal:
 	    vp->format = vpiRealVal;
-
+	    // fallthrough
 	  case vpiRealVal:
 	    vp->value.real = rval;
 	    break;
@@ -797,31 +810,26 @@ static void real_signal_value(struct t_vpi_value*vp, double rval)
 	    if (rval != rval || (rval && (rval == 0.5*rval))) {
 		  rval = 0.0;
 	    } else {
-		  if (rval >= 0.0) rval = floor(rval + 0.5);
-		  else rval = ceil(rval - 0.5);
+		  rval = vlg_round(rval);
 	    }
 	    vp->value.integer = (PLI_INT32)rval;
 	    break;
 
 	  case vpiDecStrVal:
-#if !defined(__GNUC__)
-		  if (isnan(rval))
-			  sprintf(rbuf, "%s", "nan");
-		  else
-			  sprintf(rbuf, "%0.0f", rval);
-#else
-	    sprintf(rbuf, "%0.0f", rval);
-#endif
+	    if (isnan(rval))
+		  sprintf(rbuf, "%s", "nan");
+	    else
+		  sprintf(rbuf, "%0.0f", vlg_round(rval));
 	    vp->value.str = rbuf;
 	    break;
 
 	  case vpiHexStrVal:
-	    sprintf(rbuf, "%lx", (long)rval);
+	    sprintf(rbuf, "%" PRIx64, (uint64_t)vlg_round(rval));
 	    vp->value.str = rbuf;
 	    break;
 
 	  case vpiBinStrVal: {
-		unsigned long val = (unsigned long)rval;
+		uint64_t val = (uint64_t)vlg_round(rval);
 		unsigned len = 0;
 
 		while (val > 0) {
@@ -829,7 +837,7 @@ static void real_signal_value(struct t_vpi_value*vp, double rval)
 		      val /= 2;
 		}
 
-		val = (unsigned long)rval;
+		val = (uint64_t)vlg_round(rval);
 		for (unsigned idx = 0 ;  idx < len ;  idx += 1) {
 		      rbuf[len-idx-1] = (val & 1)? '1' : '0';
 		      val /= 2;
