@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2017 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2008-2019 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -724,7 +724,7 @@ void vpip_vec4_get_value(const vvp_vector4_t&word_val, unsigned width,
 	  case vpiObjTypeVal:
 	    // Use the following case to actually set the value!
 	    vp->format = vpiVectorVal;
-
+	    // fallthrough
 	  case vpiVectorVal: {
 		unsigned hwid = (width + 31)/32;
 
@@ -784,6 +784,7 @@ void vpip_vec2_get_value(const vvp_vector2_t&word_val, unsigned width,
 
 	  case vpiObjTypeVal:
 	    vp->format = vpiIntVal;
+	    // fallthrough
 	  case vpiIntVal:
 	    vector2_to_value(word_val, vp->value.integer, signed_flag);
 	    break;
@@ -862,7 +863,7 @@ void vpip_real_get_value(double real, s_vpi_value*vp)
 	  case vpiObjTypeVal:
 	    // Use the following case to actually set the value!
 	    vp->format = vpiRealVal;
-
+	    // fallthrough
 	  case vpiRealVal:
 	    vp->value.real = real;
 	    break;
@@ -944,7 +945,7 @@ void vpip_string_get_value(const string&val, s_vpi_value*vp)
 	  case vpiObjTypeVal:
 	    // Use the following case to actually set the value!
 	    vp->format = vpiStringVal;
-
+	    // fallthrough
 	  case vpiStringVal:
 	    rbuf = (char *) need_result_buf(val.size() + 1, RBUF_VAL);
 	    strcpy(rbuf, val.c_str());
@@ -1292,7 +1293,7 @@ static vpiHandle find_name(const char *name, vpiHandle handle)
 	       * to skip ports here so the correct handle can be located. */
 	    if (vpi_get(vpiType, ref->intern[i]) == vpiPort) continue;
 	    char *nm = vpi_get_str(vpiName, ref->intern[i]);
-	    if (!strcmp(name, nm)) {
+	    if (nm && !strcmp(name, nm)) {
 		  rtn = ref->intern[i];
 		  break;
 	    } else if (vpi_get(vpiType, ref->intern[i]) == vpiMemory ||
@@ -1302,7 +1303,7 @@ static vpiHandle find_name(const char *name, vpiHandle handle)
 		  word_i = vpi_iterate(vpiMemoryWord, ref->intern[i]);
 		  while (word_i && (word_h = vpi_scan(word_i))) {
 			nm = vpi_get_str(vpiName, word_h);
-			if (!strcmp(name, nm)) {
+			if (nm && !strcmp(name, nm)) {
 			      rtn = word_h;
 			      vpi_free_object(word_i);
 			      break;
