@@ -1,7 +1,7 @@
 #ifndef IVL_vpi_priv_H
 #define IVL_vpi_priv_H
 /*
- * Copyright (c) 2001-2015 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2001-2017 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -339,7 +339,8 @@ extern vpiHandle vpip_make_int4(const char*name, int msb, int lsb,
 			       vvp_net_t*vec);
 extern vpiHandle vpip_make_var4(const char*name, int msb, int lsb,
 			       bool signed_flag, vvp_net_t*net);
-extern vpiHandle vpip_make_net4(const char*name, int msb, int lsb,
+extern vpiHandle vpip_make_net4(__vpiScope*scope,
+				const char*name, int msb, int lsb,
 				bool signed_flag, vvp_net_t*node);
 
 /*
@@ -442,8 +443,10 @@ class __vpiNamedEvent : public __vpiHandle {
       __vpiNamedEvent(__vpiScope*scope, const char*name);
       ~__vpiNamedEvent();
       int get_type_code(void) const;
+      __vpiScope*get_scope(void) const { return scope_; }
       int vpi_get(int code);
       char* vpi_get_str(int code);
+      vpiHandle vpi_put_value(p_vpi_value val, int flags);
       vpiHandle vpi_handle(int code);
 
       inline void add_vpi_callback(__vpiCallback*cb)
@@ -504,7 +507,9 @@ struct __vpiRealVar : public __vpiHandle {
 };
 
 extern struct __vpiScope* vpip_scope(__vpiRealVar*sig);
-extern vpiHandle vpip_make_real_var(const char*name, vvp_net_t*net, bool is_wire);
+extern vpiHandle vpip_make_real_var(const char*name, vvp_net_t*net);
+extern vpiHandle vpip_make_real_net(__vpiScope*scope,
+				    const char*name, vvp_net_t*net);
 
 class __vpiBaseVar : public __vpiHandle {
 
